#[non_exhaustive]pub struct AskOut {
pub decisions: IndexMap<QuestionId, UntypedDecision>,
pub scores: IndexMap<String, f64>,
pub usage: Usage,
pub backend_id: String,
pub meta: IndexMap<String, AnswerMeta>,
pub truncated_untrusted: bool,
pub pack: String,
pub pack_version: u32,
pub model: String,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.decisions: IndexMap<QuestionId, UntypedDecision>scores: IndexMap<String, f64>Choice confidence, score value, or noul probability, keyed by question id.
usage: Usagebackend_id: Stringmeta: IndexMap<String, AnswerMeta>truncated_untrusted: boolEncode replaced state.untrusted so the body fit the wire cap.
pack: StringShipped policy id. Empty when the policy was loaded from a file.
pack_version: u32model: StringModel string copied onto the wire request.
Implementations
Sourceimpl AskOut
impl AskOut
pub fn choice<T: ChoiceLabels>( &self, id: &QuestionId, ) -> Result<Decision<T>, DecodeError>
pub fn score<T: ScoreLabels>( &self, id: &QuestionId, ) -> Result<Decision<T>, DecodeError>
pub fn noul(&self, id: &QuestionId) -> Result<Decision<bool>, DecodeError>